@@ -219,7 +219,6 @@ int OPVPOutputDev::init(SplashColorMode colorModeA,
                                  const char *driverName,
 				 int outputFD,
 				 char *printerModel,
-				 int paperWidthA, int paperHeightA,
 				 int nOptions,
 				 char *optionKeys[],
 				 char *optionVals[]) {
@@ -239,8 +238,6 @@ int OPVPOutputDev::init(SplashColorMode colorModeA,
   }
   reverseVideo = reverseVideoA;
   splashColorCopy(paperColor,paperColorA);
-  paperWidth = paperWidthA;
-  paperHeight = paperHeightA;
 
   return 0;
 }
@@ -1906,8 +1903,11 @@ int OPVPOutputDev::OPVPEndDoc()
     return oprs->OPVPEndDoc();
 }
 
-int OPVPOutputDev::OPVPStartPage(char *pageInfo, int rasterWidth)
+int OPVPOutputDev::OPVPStartPage(char *pageInfo,
+  int rasterWidth, int rasterHeight)
 {
+    paperWidth = rasterWidth;
+    paperHeight = rasterHeight;
     return oprs->OPVPStartPage(pageInfo,rasterWidth);
 }
 
